@@ -46,7 +46,6 @@
 #include "searchhandler.h"
 #include "docmetainfo.h"
 #include "docentrytraverser.h"
-#include "glossary.h"
 #include "toc.h"
 #include "view.h"
 #include "infotree.h"
@@ -71,7 +70,7 @@ Navigator::Navigator( View *view, QWidget *parent )
 
     QBoxLayout *topLayout = new QVBoxLayout( this );
 
-    mSearchEdit = new KLineEdit();
+    mSearchEdit = new KLineEdit(this);
     mSearchEdit->setPlaceholderText( i18n("Search...") );
     mSearchEdit->setClearButtonEnabled(true);
     topLayout->addWidget( mSearchEdit );
@@ -221,7 +220,7 @@ History                 no X-KDE-PluginKeyword in kcmhistory.desktop
   for ( KService::List::const_iterator it = list.constBegin(); it != list.constEnd(); ++it )
   {
     KService::Ptr s(*it);
-    QString desktopFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kservices5/") + s->entryPath() );
+    const QString desktopFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kservices5/") + s->entryPath() );
     createItemFromDesktopFile( topItem, desktopFile );
     no_children_present = false;
     }
@@ -261,7 +260,7 @@ void Navigator::createItemFromDesktopFile( NavigatorItem *topItem,
     QString docPath = desktopFile.readDocPath();
     if ( !docPath.isNull() ) {
       // First parameter is ignored if second is an absolute path
-      QUrl url(QStringLiteral("help:/") + docPath);
+      const QUrl url(QStringLiteral("help:/") + docPath);
       QString icon = desktopFile.readIcon();
       if ( icon.isEmpty() ) icon = QStringLiteral("text-plain");
       DocEntry *entry = new DocEntry( desktopFile.readName(), url.url(), icon );
@@ -307,7 +306,7 @@ void Navigator::selectItem( const QUrl &url )
   NavigatorItem *item;
   item = static_cast<NavigatorItem *>( mContentsTree->currentItem() );
   if ( item && mSelected ) {
-    QUrl currentURL ( item->entry()->url() );
+    const QUrl currentURL ( item->entry()->url() );
     if ( (currentURL == url) || (currentURL == alternativeURL) ) {
       qCDebug(KHC_LOG) << "URL already shown.";
       return;
@@ -329,7 +328,7 @@ void Navigator::selectItem( const QUrl &url )
   QTreeWidgetItemIterator it( mContentsTree );
   while ( (*it) ) {
     NavigatorItem *item = static_cast<NavigatorItem *>( (*it) );
-    QUrl itemUrl( item->entry()->url() );
+    const QUrl itemUrl( item->entry()->url() );
     if ( (itemUrl == url) || (itemUrl == alternativeURL) ) {
       // If the current item was not selected and remained unchanged it
       // needs to be explicitly selected
@@ -374,9 +373,7 @@ void Navigator::slotItemSelected( QTreeWidgetItem *currentItem )
 
   item->setExpanded( !item->isExpanded() );
 
-  QUrl url ( item->entry()->url() );
-
-  
+  const QUrl url ( item->entry()->url() );
   
   if ( url.scheme() == QLatin1String("khelpcenter") ) {
       mView->closeUrl();
@@ -385,7 +382,7 @@ void Navigator::slotItemSelected( QTreeWidgetItem *currentItem )
       showOverview( item, url );
   } else {
    
-    emit itemSelected( url.url() );
+    Q_EMIT itemSelected( url.url() );
   }
 }
 
@@ -429,7 +426,7 @@ void Navigator::showOverview( NavigatorItem *item, const QUrl &url )
     title = item->entry()->name();
     name = item->entry()->name();
 
-    QString info = item->entry()->info();
+    const QString info = item->entry()->info();
     if ( !info.isEmpty() ) content = QLatin1String("<p>") + info + QLatin1String("</p>\n");
 
     childCount = item->childCount();
@@ -500,10 +497,10 @@ void Navigator::slotSearch()
 
   if ( mSearchEngine->isRunning() ) return;
 
-  QString words = mSearchEdit->text();
-  QString method = mSearchWidget->method();
-  int pages = mSearchWidget->pages();
-  QStringList scope = mSearchWidget->scope();
+  const QString words = mSearchEdit->text();
+  const QString method = mSearchWidget->method();
+  const int pages = mSearchWidget->pages();
+  const QStringList scope = mSearchWidget->scope();
 
   qCDebug(KHC_LOG) << "Navigator::slotSearch() words: " << words;
   qCDebug(KHC_LOG) << "Navigator::slotSearch() scope: " << scope;
@@ -528,7 +525,7 @@ void Navigator::slotShowSearchResult( const QString &url )
   QString u = url;
   u.replace( QStringLiteral("%k"), mSearchEdit->text() );
 
-  emit itemSelected( u );
+  Q_EMIT itemSelected( u );
 }
 
 void Navigator::slotSearchFinished()
@@ -601,7 +598,7 @@ void Navigator::slotDelayedIndexingStart()
   mIndexingQueue.clear();
 
   const DocEntry::List &entries = DocMetaInfo::self()->docEntries();
-  foreach ( DocEntry *entry, entries ) {
+  for ( DocEntry *entry : entries ) {
     if ( mSearchEngine->needsIndex( entry ) ) {
       mIndexingQueue.append( entry );
     }
@@ -611,7 +608,7 @@ void Navigator::slotDelayedIndexingStart()
     return;
   }
 
-  emit setStatusBarText( i18n( "Updating search index..." ) );
+  Q_EMIT setStatusBarText( i18n( "Updating search index..." ) );
 
   mIndexingTimer.start();
 
@@ -622,7 +619,7 @@ void Navigator::slotDoIndexWork()
 {
   if ( mIndexingQueue.isEmpty() ) {
     mIndexingTimer.stop();
-    emit setStatusBarText( i18n( "Updating search index... done." ) );
+    Q_EMIT setStatusBarText( i18n( "Updating search index... done." ) );
     mIndexingBar->hide();
     mSearchWidget->searchIndexUpdated();
     return;
